# Sample Chronograf Dashboards

This folder contains several sample dashboards for use in Chronograf.

## Loading a dashboard

To load a dashboard into an existing Chronograf service, use the following `curl` command:

```shell
curl -i -XPOST -H "Content-Type: application/json" http://<service IP>:8888/chronograf/v1/dashboards -d @someFile.json
```

## Saving a dashboard

To save a dashboard use:

```shell
wget http://<service IP>:8888/chronograf/v1/dashboards/<dashboard ID> -O - | jq '.' > someFile.json
```

The pipe into the `jq` command is not strictly necessary, it is there to pretty-print the JSON.

## Overview

### dc_dash.json

Displays the average CPU usage over time for an entire data centre. It has a dashboard variable for the `location` field.

### sf_dash.json

The service function dashboard has two dashboard variables to choose two different service functions to display side by side (left and right column).

Each column displays the total network traffic sent and received in MB over time (1 minute intervals) in the top chart and the average network traffic rate in MB/s for sent and received traffic in the bottom chart (1 minute intervals).

To get the top chart, a nested select statement is used:

```sql
select sum(RX_MB) as total_RX_MB, sum(TX_MB) as total_TX_MB from (SELECT last("bytes_recv") / 1048576 AS "RX_MB", last("bytes_sent") / 1048576 AS "TX_MB" FROM "MSDemo"."autogen"."net" WHERE time > :dashboardTime: AND "sf"=:sf1: GROUP BY time(1m), ipendpoint FILL(null)) group by time(1m)
```

(The constant 1048576 is 1024*1024)

The inner select groups by ipendpoint and time, taking the maximum value in each time period for each ipendpoint and the outer select queries over the result of the inner select but then groups only by time.

The derivative of the first chart requires a further nested select:

```sql
select derivative(total_RX_MB, 1m) / 60 as RX_MB_per_s, derivative(total_TX_MB, 1m) / 60 as TX_MB_per_s from (select sum(RX_MB) as total_RX_MB, sum(TX_MB) as total_TX_MB from (SELECT last("bytes_recv") / 1048576 AS "RX_MB", last("bytes_sent") / 1048576 AS "TX_MB" FROM "MSDemo"."autogen"."net" WHERE time > :dashboardTime: AND "sf"=:sf1: GROUP BY time(1m), ipendpoint FILL(null)) group by time(1m))
```

The outer-most select taakes the derivative of the first chart for each data set separately. The derivative function is parameterised to understand it is over a 1m period but then the result is divided by 60 to give an average MB/s in each 1 minute period.

### minio_dash.json

The minio dashboard has two dashboard variables to choose two different ipendpoints to display side by side (left and right column). Minio endpoints must be chosen for all features to work.

The top chart shows the percentage of requests being served in less than a fixed set up time periods. This performance metric would highlight a service endpoint which was struggling to service demand.

The other charts show network traffic using a similar formulation to the `sf_dash` described above.

### nginx_dash.json

There are no dashboard variables on this dashboard: it is hard-coded to show the `nginx_1_ep1` and `nginx_1_ep2` endpoints. Various charts (network, CPU, responses per second) are displayed.
